Stan Math Library: stan/math/prim/scal/fun/corr_constrain.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

corr_constrain.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_CORR_CONSTRAIN_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_CORR_CONSTRAIN_HPP
3
4 #include <stan/math/prim/scal/fun/log1m.hpp>
5 #include <cmath>
6
7 namespace stan {
8
9 namespace math {
10
23 template <typename T>
24 inline
25 T corr_constrain(const T x) {
26 return tanh(x);
27 }
28
41 template <typename T>
42 inline
43 T corr_constrain(const T x, T& lp) {
44 using stan::math::log1m;
45 T tanh_x = tanh(x);
46 lp += log1m(tanh_x * tanh_x);
47 return tanh_x;
48 }
49
50 }
51
52 }
53
54 #endif
stan
Definition: log_sum_exp.hpp:8
stan::math::tanh
fvar< T > tanh(const fvar< T > &x)
Definition: tanh.hpp:14
log1m.hpp
stan::math::log1m
fvar< T > log1m(const fvar< T > &x)
Definition: log1m.hpp:16
stan::math::corr_constrain
T corr_constrain(const T x)
Return the result of transforming the specified scalar to have a valid correlation value between -1 a...
Definition: corr_constrain.hpp:25

[ Stan Home Page ] © 2011–2016, Stan Development Team.